2024-03-13 Version: 1.0.12
- Update API BatchSendMail: add param UnSubscribeFilterLevel.
- Update API BatchSendMail: add param UnSubscribeLinkType.
- Update API SenderStatisticsDetailByParam: update response param.
- Update API SingleSendMail: add param UnSubscribeFilterLevel.
- Update API SingleSendMail: add param UnSubscribeLinkType.


2024-02-20 Version: 1.0.11
- Update API BatchSendMail: add param UnSubscribeFilterLevel.
- Update API BatchSendMail: add param UnSubscribeLinkType.
- Update API SingleSendMail: add param UnSubscribeFilterLevel.
- Update API SingleSendMail: add param UnSubscribeLinkType.


2024-01-15 Version: 1.0.10
- Generated python 2015-11-23 for Dm.

2023-12-12 Version: 1.0.9
- Generated python 2015-11-23 for Dm.

2023-09-13 Version: 1.0.8
- Generated python 2015-11-23 for Dm.

2023-08-29 Version: 1.0.7
- Generated python 2015-11-23 for Dm.

2023-07-27 Version: 1.0.6
- Fix bugs for GetTrackList and GetTrackListByMailFromAndTagName.
- Fixed bugs for GetTrackListByMailFromAndTagName.
- Add field SpfRecordV2, DkimRR, DkimPublicKey, DkimAuthStatus.

2022-09-29 Version: 1.0.5
- Automatically generate sdk tasks.

2022-08-02 Version: 1.0.4
- The input parameter IpProtection of UpdateIpProtection API  is corrected to be required. 

2022-05-20 Version: 1.0.3
- Ip related APIs are changed to visiable and QPM is set as 60 .

2022-04-21 Version: 1.0.2
- Some APIs are changed to invisiable.
- Wrong type of SenderStatisticsDetailByParam reponse fields is fixed.

2022-04-13 Version: 1.0.1
- Some APIs are changed to invisiable.
- Wrong type of QueryInvalidAddress reponse fields is fixed.

2020-12-30 Version: 1.0.0
- AMP Version Change.

